ZydisEncoderEncodeInstructionAbsolute

Function ZydisEncoderEncodeInstructionAbsolute 

pub unsafe extern "C" fn ZydisEncoderEncodeInstructionAbsolute(
    request: *mut ZydisEncoderRequest,
    buffer: *mut c_void,
    length: *mut ZyanUSize,
    runtime_address: ZyanU64,
) -> ZyanStatus
Encodes instruction with semantics specified in encoder request structure. This function expects absolute addresses inside encoder request instead of EIP/RIP-relative values. Function predicts final instruction length prior to encoding and writes back calculated relative operands to provided encoder request.

@param request A pointer to the ZydisEncoderRequest struct. @param buffer A pointer to the output buffer receiving encoded instruction. @param length A pointer to the variable containing length of the output buffer. Upon successful return this variable receives length of the encoded instruction. @param runtime_address The runtime address of the instruction.

@return A zyan status code.