ZyanString_

Struct ZyanString_ 

#[repr(C)]
pub struct ZyanString_ { pub flags: ZyanStringFlags, pub vector: ZyanVector, }
Defines the ZyanString struct.

The ZyanString type is implemented as a size-prefixed string - which allows for a lot of performance optimizations. Nevertheless null-termination is guaranteed at all times to provide maximum compatibility with default C-style strings (use ZyanStringGetData to access the C-style string).

All fields in this struct should be considered as “private”. Any changes may lead to unexpected behavior.

Fields

flags: ZyanStringFlags

String flags.

vector: ZyanVector

The vector that contains the actual string.