#[repr(transparent)]pub struct ZydisOperandType_(pub c_uint);Expand description
Defines the ZydisOperandType enum.
Tuple Fields
0: c_uintImplementations
Sourceimpl ZydisOperandType_
impl ZydisOperandType_
Sourcepub const ZYDIS_OPERAND_TYPE_UNUSED: ZydisOperandType_
pub const ZYDIS_OPERAND_TYPE_UNUSED: ZydisOperandType_
The operand is not used.
Sourceimpl ZydisOperandType_
impl ZydisOperandType_
Sourcepub const ZYDIS_OPERAND_TYPE_REGISTER: ZydisOperandType_
pub const ZYDIS_OPERAND_TYPE_REGISTER: ZydisOperandType_
The operand is a register operand.
Sourceimpl ZydisOperandType_
impl ZydisOperandType_
Sourcepub const ZYDIS_OPERAND_TYPE_MEMORY: ZydisOperandType_
pub const ZYDIS_OPERAND_TYPE_MEMORY: ZydisOperandType_
The operand is a memory operand.
Sourceimpl ZydisOperandType_
impl ZydisOperandType_
Sourcepub const ZYDIS_OPERAND_TYPE_POINTER: ZydisOperandType_
pub const ZYDIS_OPERAND_TYPE_POINTER: ZydisOperandType_
The operand is a pointer operand with a segment:offset lvalue.
Sourceimpl ZydisOperandType_
impl ZydisOperandType_
Sourcepub const ZYDIS_OPERAND_TYPE_IMMEDIATE: ZydisOperandType_
pub const ZYDIS_OPERAND_TYPE_IMMEDIATE: ZydisOperandType_
The operand is an immediate operand.
Sourceimpl ZydisOperandType_
impl ZydisOperandType_
Sourcepub const ZYDIS_OPERAND_TYPE_MAX_VALUE: ZydisOperandType_
pub const ZYDIS_OPERAND_TYPE_MAX_VALUE: ZydisOperandType_
Maximum value of this enum.
Sourceimpl ZydisOperandType_
impl ZydisOperandType_
Sourcepub const ZYDIS_OPERAND_TYPE_REQUIRED_BITS: ZydisOperandType_
pub const ZYDIS_OPERAND_TYPE_REQUIRED_BITS: ZydisOperandType_
The minimum number of bits required to represent all values of this enum.