#[repr(C, packed(1))]pub struct ZydisShortString_ {
pub data: *const c_char,
pub size: ZyanU8,
}Expand description
Defines the ZydisShortString struct.
This compact struct is mainly used for internal string-tables to save up some bytes.
All fields in this struct should be considered as “private”. Any changes may lead to unexpected behavior.
Fields
data: *const c_charThe buffer that contains the actual (null-terminated) string.
size: ZyanU8The length (number of characters) of the string (without 0-termination).