ZyanString

Type Alias ZyanString 

pub type ZyanString = ZyanString_;
Defines the ZyanString struct.

The ZyanString type is implemented as a size-prefixed string - which allows for a lot of performance optimizations. Nevertheless null-termination is guaranteed at all times to provide maximum compatibility with default C-style strings (use ZyanStringGetData to access the C-style string).

All fields in this struct should be considered as “private”. Any changes may lead to unexpected behavior.

Aliased Type

#[repr(C)]
pub struct ZyanString { pub flags: u8, pub vector: ZyanVector_, }

Fields

flags: u8

String flags.

vector: ZyanVector_

The vector that contains the actual string.