ZydisEncoderRequest

Type Alias ZydisEncoderRequest 

pub type ZydisEncoderRequest = ZydisEncoderRequest_;
Main structure consumed by the encoder. It represents full semantics of an instruction.

Aliased Type

#[repr(C)]
pub struct ZydisEncoderRequest { pub machine_mode: ZydisMachineMode_, pub allowed_encodings: ZydisEncodableEncoding_, pub mnemonic: ZydisMnemonic_, pub prefixes: u64, pub branch_type: ZydisBranchType_, pub branch_width: ZydisBranchWidth_, pub address_size_hint: ZydisAddressSizeHint_, pub operand_size_hint: ZydisOperandSizeHint_, pub operand_count: u8, pub operands: [ZydisEncoderOperand_; 5], pub evex: ZydisEncoderRequest__ZydisEncoderRequestEvexFeatures_, pub mvex: ZydisEncoderRequest__ZydisEncoderRequestMvexFeatures_, }

Fields

machine_mode: ZydisMachineMode_

The machine mode used to encode this instruction.

allowed_encodings: ZydisEncodableEncoding_

This optional field can be used to restrict allowed physical encodings for desired instruction. Some mnemonics can be supported by more than one encoding, so this field can resolve ambiguities e.g. you can disable AVX-512 extensions by prohibiting usage of EVEX prefix and allow only VEX variants.

mnemonic: ZydisMnemonic_

The instruction-mnemonic.

prefixes: u64

A combination of requested encodable prefixes (ZYDIS_ATTRIB_HAS_* flags) for desired instruction. See ZYDIS_ENCODABLE_PREFIXES for list of available prefixes.

branch_type: ZydisBranchType_

Branch type (required for branching instructions only). Use ZYDIS_BRANCH_TYPE_NONE to let encoder pick size-optimal branch type automatically (short and near are prioritized over far).

branch_width: ZydisBranchWidth_

Specifies physical size for relative immediate operands. Use ZYDIS_BRANCH_WIDTH_NONE to let encoder pick size-optimal branch width automatically. For segment:offset far branches this field applies to physical size of the offset part. For branching instructions without relative operands this field affects effective operand size attribute.

address_size_hint: ZydisAddressSizeHint_

Optional address size hint used to resolve ambiguities for some instructions. Generally encoder deduces address size from ZydisEncoderOperand structures that represent explicit and implicit operands. This hint resolves conflicts when instruction’s hidden operands scale with address size attribute.

operand_size_hint: ZydisOperandSizeHint_

Optional operand size hint used to resolve ambiguities for some instructions. Generally encoder deduces operand size from ZydisEncoderOperand structures that represent explicit and implicit operands. This hint resolves conflicts when instruction’s hidden operands scale with operand size attribute.

operand_count: u8

The number of visible (explicit) instruction operands.

The encoder does not care about hidden (implicit) operands.

operands: [ZydisEncoderOperand_; 5]

Detailed info for all explicit and implicit instruction operands.

evex: ZydisEncoderRequest__ZydisEncoderRequestEvexFeatures_mvex: ZydisEncoderRequest__ZydisEncoderRequestMvexFeatures_