#[repr(C)]pub struct ZyanString_ {
pub flags: ZyanStringFlags,
pub vector: ZyanVector,
}Expand description
Defines the ZyanString struct.
The ZyanString type is implemented as a size-prefixed string - which allows for a lot of
performance optimizations.
Nevertheless null-termination is guaranteed at all times to provide maximum compatibility with
default C-style strings (use ZyanStringGetData to access the C-style string).
All fields in this struct should be considered as “private”. Any changes may lead to unexpected behavior.
Fields
flags: ZyanStringFlagsString flags.
vector: ZyanVectorThe vector that contains the actual string.