pub type ZydisShortString = ZydisShortString_;Expand description
Defines the ZydisShortString struct.
This compact struct is mainly used for internal string-tables to save up some bytes.
All fields in this struct should be considered as “private”. Any changes may lead to unexpected behavior.
Aliased Type
#[repr(C, packed(1))]pub struct ZydisShortString {
pub data: *const i8,
pub size: u8,
}Fields
data: *const i8The buffer that contains the actual (null-terminated) string.
size: u8The length (number of characters) of the string (without 0-termination).